@@ -17,6 +17,7 @@
 #'      \item{He}{Expected heterozygosity}
 #'      \item{Ho}{Observed heterozygosity}
 #'      \item{Fis}{Wright's Inbreeding coefficient (size corrected).}
+#'      \item{Pe}{Locus polymorphic index.}
 #'    }
 #' @return A \code{data.frame} with columns for strata, diversity (mode), and potentially P(mode=0).
 #' @export
@@ -30,7 +31,7 @@
 #'  Population <- c(rep("Pop-A",5),rep("Pop-B",5))
 #'  df <- data.frame( Population, TPI=locus, PGM=locus2 )
 #'  genetic_diversity( df, mode="Ae")
-genetic_diversity <- function( x, stratum=NULL, mode=c("A","Ae","A95","He", "Ho", "Fis")[2] ){
+genetic_diversity <- function( x, stratum=NULL, mode=c("A","Ae","A95","He", "Ho", "Fis","Pe")[2] ){
   
   if( missing(x) )
     stop("You must pass a data.frame to the genetic_diversity() function.")
@@ -66,11 +67,10 @@ genetic_diversity <- function( x, stratum=NULL, mode=c("A","Ae","A95","He", "Ho"
     ret <- Ho(x)
   else if( mode == "fis")
     ret <- Fis(x)
+  else if( mode == "pe")
+    ret <- Pe(x)
   else
     stop(paste("The type of diversity measure '", mode, "' you requested was not recognized.", sep=""))
-  
-  
-  
     
   
   return( ret )
