@@ -13,7 +13,15 @@
 #' loci <- c( locus(1:2), locus(c(1,1) ) )
 #' ploidy( loci )
 ploidy <- function ( x ) {
-  if( length(x)>1 )
+  if( is(x,"data.frame")) {
+    loci <- column_class(x,"locus")
+    K <- length(loci)
+    ret <- data.frame(Locus=loci,Ploidy=0)
+    for( locus in loci )
+      ret$Ploidy[ ret$Locus==locus] <- mean(ploidy( x[[locus]] ))
+    return(ret)
+  }
+  else if( length(x)>1 )
     return( unlist(lapply(x,ploidy) ) )
   else
     return( length( alleles( x ) ) )
