@@ -28,4 +28,7 @@ test_that("testing",{
   expect_that( names(p), is_equivalent_to(c("MomID","OffID","DadID","Fij")))
   expect_that( sum(p$Fij, na.rm=TRUE), equals(10) )
   
+  p1 <- paternity( offs, adults[1,], adults, strict=TRUE )
+  expect_that( nrow(p)>nrow(p1), is_true())
+  
 })
\ No newline at end of file
